@@ -6,7 +6,7 @@ import inspect
 import json
 import logging
 import uuid
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, get_type_hints
 
 if TYPE_CHECKING:
     from collections.abc import AsyncGenerator, Callable
@@ -177,8 +177,17 @@ class ScenarioMixin:
                 safe_env_name = env_name.replace("_", "-")
                 prompt_id = f"{safe_env_name}:{scenario_name}"
                 logger.debug("Remote scenario (adding namespace): prompt_id=%s", prompt_id)
+            # Serialize args for MCP prompt (only supports string values)
+            # JSON-encode any non-string values so they can be deserialized on the other side
+            serialized_args: dict[str, str] = {}
+            for key, value in args.items():
+                if isinstance(value, str):
+                    serialized_args[key] = value
+                else:
+                    serialized_args[key] = json.dumps(value)
+
             try:
-                result = await self.get_prompt(prompt_id, args)  # type: ignore[attr-defined]
+                result = await self.get_prompt(prompt_id, serialized_args)  # type: ignore[attr-defined]
             except Exception as e:
                 # Fetch available scenarios for error context
                 try:
@@ -384,9 +393,49 @@ class ScenarioMixin:
             scenario_fn = fn
             scenario_name_ref = scenario_name
 
+            # Resolve parameter type hints for deserialization
+            # Use get_type_hints() to handle `from __future__ import annotations`
+            # which makes annotations lazy strings (PEP 563)
+            # MCP prompts only support string arguments, so we JSON-serialize complex types
+            # and use Pydantic TypeAdapter to properly deserialize them
+            try:
+                param_annotations = get_type_hints(fn)
+            except Exception:
+                # Fall back to raw annotations if get_type_hints fails
+                param_annotations = {
+                    p.name: p.annotation
+                    for p in sig.parameters.values()
+                    if p.annotation is not inspect.Parameter.empty
+                }
+
             async def prompt_handler(**handler_args: Any) -> list[str]:
-                # Create generator instance
-                gen = scenario_fn(**handler_args)
+                from pydantic import TypeAdapter
+
+                # Deserialize JSON-encoded arguments using Pydantic TypeAdapter
+                # This properly handles: Pydantic models, enums, datetime, lists, dicts
+                deserialized_args: dict[str, Any] = {}
+                for arg_name, arg_value in handler_args.items():
+                    annotation = param_annotations.get(arg_name)
+                    if (
+                        annotation is not None
+                        and annotation is not str
+                        and isinstance(arg_value, str)
+                    ):
+                        # Try TypeAdapter.validate_json for proper type coercion
+                        try:
+                            adapter = TypeAdapter(annotation)
+                            deserialized_args[arg_name] = adapter.validate_json(arg_value)
+                        except Exception:
+                            # Fall back to plain json.loads if TypeAdapter fails
+                            try:
+                                deserialized_args[arg_name] = json.loads(arg_value)
+                            except json.JSONDecodeError:
+                                deserialized_args[arg_name] = arg_value
+                    else:
+                        deserialized_args[arg_name] = arg_value
+
+                # Create generator instance with deserialized args
+                gen = scenario_fn(**deserialized_args)
 
                 # Run setup phase (code before first yield)
                 prompt_text = await gen.__anext__()
